# PPG-log
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/ppg-log)](https://pypi.org/project/ppg-log/)
[![PyPI](https://img.shields.io/pypi/v/ppg-log)](https://pypi.org/project/ppg-log/)
[![PyPI - License](https://img.shields.io/pypi/l/ppg-log?color=magenta)](https://github.com/sco1/ppg-log/blob/main/LICENSE)
[![pre-commit.ci status](https://results.pre-commit.ci/badge/github/sco1/ppg-log/main.svg)](https://results.pre-commit.ci/latest/github/sco1/ppg-log/main)
[![Code style: black](https://img.shields.io/badge/code%20style-black-black)](https://github.com/psf/black)
[![Open in Visual Studio Code](https://img.shields.io/badge/Open%20in-VSCode.dev-blue)](https://vscode.dev/github.com/sco1/ppg-log)

Helper Tools for PPG FlySight Flight Log Management
